Selector

Enum Selector 

pub enum Selector<K> {
    ByKey(K),
    ByIndex(usize),
}
Topology selector.

Identifies topology by key or index. Keys behave as an absolute selector and uniquely identify a single topological structure. Indices behave as a relative selector and identify topological structures relative to some other structure. Selector is used by operations that support both of these selection mechanisms.

An index is typically used to select a neighbor or contained (and ordered) topological structure, such as a neighboring face.

Examples

Splitting a face by index (of its contained vertices):

use plexus::graph::MeshGraph;
use plexus::prelude::*;
use plexus::primitive::cube::Cube;

let mut graph = Cube::new()
    .polygons_with_position()
    .collect::<MeshGraph<Triplet<_>>>();
let abc = graph.faces().nth(0).unwrap().key();
graph
    .face_mut(abc)
    .unwrap()
    .split(ByIndex(0), ByIndex(2))
    .unwrap();

Variants



ByKey(K)



ByIndex(usize)

Implementations

Source

impl<K> Selector<K>

pub fn key_or_else<E, F>(self, f: F) -> Result<K, GraphError>
where E: Into<GraphError>, F: Fn(usize) -> Result<K, E>,

Gets the selector’s key or passes its index to a function to resolve the key.

pub fn index_or_else<E, F>(self, f: F) -> Result<usize, GraphError>
where E: Into<GraphError>, F: Fn(K) -> Result<usize, E>,

Gets the selector’s index or passes its key to a function to resolve the index.