InteriorPathView

Struct InteriorPathView 

pub struct InteriorPathView<M, G>
where M: Reborrow, M::Target: AsStorage<ArcPayload<G>> + Consistent, G: Geometry,
{ /* private fields */ }
View of an interior path.

Interior paths are closed paths formed by arcs and their immediate neighboring arcs. In a consistent graph, every arc forms such a path. Such paths may or may not be occupied by faces.

Interior paths have no associated payload and do not directly expose geometry.

See the module documentation for more information about topological views.

Implementations

Source

impl<'a, M, G> InteriorPathView<&'a mut M, G>
where M: AsStorage<ArcPayload<G>> + Consistent, G: 'a + Geometry,

pub fn into_ref(self) -> InteriorPathView<&'a M, G>

Converts a mutable view into an immutable view.

This is useful when mutations are not (or no longer) needed and mutual access is desired.

pub fn with_ref<T, K, F>(self, f: F) -> Either<Result<T, GraphError>, Self>
where T: FromKeyedSource<(K, &'a mut M)>, F: FnOnce(InteriorPathView<&M, G>) -> Option<K>,

Reborrows the view and constructs another mutable view from a given key.

This allows for fallible traversals from a mutable view without the need for direct access to the source MeshGraph. If the given function emits a key, then that key will be used to convert this view into another. If no key is emitted, then the original mutable view is returned.

Source

impl<M, G> InteriorPathView<M, G>
where M: Reborrow, M::Target: AsStorage<ArcPayload<G>> + Consistent, G: Geometry,

pub fn arity(&self) -> usize

Gets the arity of the interior path. This is the number of arcs that form the path.

pub fn arcs(&self) -> impl Clone + Iterator<Item = ArcView<&M::Target, G>>

Gets an iterator of views over the arcs within the interior path.

Source

impl<M, G> InteriorPathView<M, G>
where M: Reborrow, M::Target: AsStorage<ArcPayload<G>> + AsStorage<VertexPayload<G>> + Consistent, G: Geometry,

pub fn into_arc(self) -> ArcView<M, G>

Converts the interior path into its originating arc.

pub fn arc(&self) -> ArcView<&M::Target, G>

Gets the originating arc of the interior path.

pub fn distance( &self, source: Selector<VertexKey>, destination: Selector<VertexKey>, ) -> Result<usize, GraphError>

Gets the distance (number of arcs) between two vertices within the interior path.

pub fn vertices( &self, ) -> impl Clone + Iterator<Item = VertexView<&M::Target, G>>

Gets an iterator of views over the vertices within the interior path.

Source

impl<M, G> InteriorPathView<M, G>
where M: Reborrow, M::Target: AsStorage<ArcPayload<G>> + AsStorage<FacePayload<G>> + Consistent, G: Geometry,

pub fn into_face(self) -> Option<FaceView<M, G>>

Converts the interior path into its face.

If the path has no associated face, then None is returned.

pub fn face(&self) -> Option<FaceView<&M::Target, G>>

Gets the face of the interior path.

If the path has no associated face, then None is returned.

Source

impl<'a, M, G> InteriorPathView<&'a mut M, G>
where M: AsStorage<VertexPayload<G>> + AsStorage<ArcPayload<G>> + AsStorage<FacePayload<G>> + Default + Mutable<G>, G: 'a + Geometry,

pub fn get_or_insert_face(self) -> FaceView<&'a mut M, G>

Gets the face of the interior path or inserts a face if one does not already exist.

Returns the inserted face.

pub fn get_or_insert_face_with<F>(self, f: F) -> FaceView<&'a mut M, G>
where F: FnOnce() -> G::Face,

Gets the face of the interior path or inserts a face if one does not already exist.

If a face is inserted, then the given function is used to get the geometry for the face.

Returns the inserted face.